@@ -1,4 +1,4 @@
-# $Id: SSH2.pm,v 1.42 2008/09/25 21:06:25 turnstep Exp $
+# $Id: SSH2.pm,v 1.43 2008/10/16 13:48:58 turnstep Exp $
 
 package Net::SSH::Perl::SSH2;
 use strict;
@@ -24,7 +24,7 @@ sub _dup {
     my($fh, $mode) = @_;
     my $dup = Symbol::gensym;
     my $str = "${mode}&$fh";
-    open $dup, $str;
+    open $dup, '<', $str or die "Could not dupe: $!\n";
     $dup;
 }
 
